@@ -117,16 +117,8 @@ colorQuantiles <- function(soilColors, p = c(0.05, 0.5, 0.95)) {
 
 
   ## find closest observed color to L1 median via CIE2000 distance metric
-  ## requires farver >= 2.0.3
-  if( !requireNamespace('farver', quietly = TRUE) || packageVersion("farver") < '2.0.3' ) {
-    message('CIE2000 comparisons require `farver` version 2.0.3 or greater, using Euclidean distance in CIELAB instead', call.=FALSE)
-    d <- farver::compare_colour(from=L1, to=soilColors.lab, from_space='lab', method = 'cie2000')
-  } else {
-    # backup plan using Euclidean distance in CIELAB
-    d <- sqrt(rowSums(sweep(soilColors.lab, MARGIN = 2, STATS=L1, FUN = '-')^2))
-  }
-
-
+  d <- farver::compare_colour(from=L1, to=soilColors.lab, from_space='lab', method = 'cie2000')
+  
   # assign L1 color
   L1.color <- soilColors[which.min(d)]
 
