@@ -15,6 +15,7 @@
 #' @return a list of internally-used ordering vectors and graphical offsets / scaling factors
 #'
 #' @keywords manip
+#' @export
 #' @examples
 #'
 #' # sample data
@@ -25,40 +26,52 @@
 #' pos <- c(1, 1.1, 3, 4, 5, 5.2, 7, 8, 9, 10)
 #'
 #' # try it
-#' explainPlotSPC(sp4, name='name', relative.pos=pos)
+#' explainPlotSPC(sp4, name = 'name', relative.pos=pos)
 #'
 #' # attempt to fix using an integer sequence, short-circut will prevent adjustments
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(1:10))
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(1:10))
 #'
 #' # attempt to adjust using defaults
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos))
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(pos))
 #'
 #' # attempt to adjust and tinker with defaults
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos, adj = 0.2))
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(pos, adj = 0.2))
 #'
-#' # repeatable adjustments
-#' set.seed(10101)
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos, thresh = 0.7))
+#' # enforce larger space between
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(pos, thresh = 0.7))
 #'
 #' # more complex adjustments required
-#' pos <- c(1, 2, 3, 3.3, 5, 5.1, 5.5, 8, 9, 9.1)
+#' pos <- c(1, 2, 3, 3.3, 5, 5.1, 5.5, 8, 9, 10)
 #'
 #' # tinker
-#' explainPlotSPC(sp4, name='name', relative.pos=pos)
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos))
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos, thresh = 0.7))
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos, thresh=0.7, adj = 0.2))
-#'
-#' # no solution possible given these constraints
-#' explainPlotSPC(sp4, name='name', relative.pos=fixOverlap(pos, thresh=1, adj = 0.2))
+#' explainPlotSPC(sp4, name = 'name', relative.pos = pos)
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(pos))
+#' 
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(pos, 
+#' thresh = 0.7))
+#' 
+#' explainPlotSPC(sp4, name = 'name', relative.pos = fixOverlap(pos, 
+#' thresh = 0.7, adj = 0.2))
 #'
+#' # SANN: solution requires many iterations, and will not always converge
+#' explainPlotSPC(sp4, name = 'name', 
+#' relative.pos = fixOverlap(pos, thresh = 0.85, adj = 0.2)
+#' )
+#' 
+#' # electrostatics: solution requires larger charge (q)
+#' explainPlotSPC(sp4, name = 'name', 
+#' relative.pos = fixOverlap(pos, thresh = 0.85, method = 'E', q = 2)
+#' )
 #'
 explainPlotSPC <- function(x, ...) {
   plotSPC(x, id.style='side', ...)
   box()
   
+  # figure coordinates
+  .usr <- par('usr')
+  
   # get last plot parameters
-  lsp <- get('last_spc_plot', envir=aqp.env)
+  lsp <- get('last_spc_plot', envir = aqp.env)
   
   # get max depth by profile
   max.depths <- profileApply(x, max)
@@ -76,15 +89,21 @@ explainPlotSPC <- function(x, ...) {
   # suitable location for x-space annotation
   # index of last profile + some
   x.space.x <- lsp$n + (length(x) * 0.05)
-  # 95% of total scaled depths
-  x.space.y <- max(scaled.max.depths) * 0.95
+  
+  # 95% of lower figure coordinates
+  x.space.y <- .usr[3] * 0.95
   
   # original profile index text y-coordinate
   # roughly 10% of the max(transformed depths)
   original.profile.idx.y <- lsp$y.offset + (-max(scaled.max.depths) * 0.08)
   
+  # segment depth starting locations
+  # 90% of bottom of plotting region ----> scaled max depths 
+  # or max(scaled depths), whichever is larger
+  .segment.bottom.y <- pmax(.usr[3] * 0.9, max(scaled.max.depths, na.rm = TRUE))
+  
   # inspect plotting area, very simple to overlay graphical elements
-  segments(x0 = lsp$x0, x1=lsp$x0, y0=lsp$max.depth, y1=scaled.max.depths, lty=3, lwd=2, col='darkgreen')
+  segments(x0 = lsp$x0, x1 = lsp$x0, y0 = .segment.bottom.y, y1 = scaled.max.depths, lty=3, lwd=2, col='darkgreen')
   
   # profiles are centered at integers, from 1 to length(obj)
   axis(1, line=0.25, at=round(lsp$x0, 2), cex.axis=0.75, font=4, col='darkgreen', col.axis='darkgreen', lwd=2)
@@ -113,6 +132,14 @@ explainPlotSPC <- function(x, ...) {
   text(x=lsp$x0, y=original.profile.idx.y, labels=lsp$plot.order, col='darkred', font=4, cex=0.75)
   mtext('original profile index', side=3, line=0, font=4, col='darkred')
   
+  # hz depth label adjustment index
+  if(! all(is.na(lsp$hz.depth.LAI))) {
+    # annotate
+    .LAI.txt <- sprintf("LAI\n%s", round(lsp$hz.depth.LAI, 2))
+    text(x = lsp$x0 + lsp$width, y = .segment.bottom.y, pos = 4, cex = 0.66, labels = .LAI.txt)
+  }
+  
+  
   invisible(lsp)
 }
 
